.danger_marker {
  position:absolute;
  background:rgba(200,50,50,1);
  z-index:20
}

.success_marker {
  position:absolute;
  background:rgba(50,200,100,1);
  z-index:20
}

.info_marker {
  position:absolute;
  background:rgba(50,100,200,1);
  z-index:20
}

.warning_marker {
  position:absolute;
  background:rgba(255,105,50,1);
  z-index:20
}